==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/cs.inc.php <==
<?php
$translations = array(
	'Login' => 'Přihlásit se',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Odhlášení proběhlo v pořádku.',
	'Invalid credentials.' => 'Neplatné přihlašovací údaje.',
	'Server' => 'Server',
	'Username' => 'Uživatel',
	'Password' => 'Heslo',
	'Select database' => 'Vybrat databázi',
	'Invalid database.' => 'Nesprávná databáze.',
	'Create new database' => 'Vytvořit novou databázi',
	'Table has been dropped.' => 'Tabulka byla odstraněna.',
	'Table has been altered.' => 'Tabulka byla změněna.',
	'Table has been created.' => 'Tabulka byla vytvořena.',
	'Alter table' => 'Pozměnit tabulku',
	'Create table' => 'Vytvořit tabulku',
	'Table name' => 'Název tabulky',
	'engine' => 'úložiště',
	'collation' => 'porovnávání',
	'Column name' => 'Název sloupce',
	'Type' => 'Typ',
	'Length' => 'Délka',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Volby',
	'Save' => 'Uložit',
	'Drop' => 'Odstranit',
	'Database has been dropped.' => 'Databáze byla odstraněna.',
	'Database has been created.' => 'Databáze byla vytvořena.',
	'Database has been renamed.' => 'Databáze byla přejmenována.',
	'Database has been altered.' => 'Databáze byla změněna.',
	'Alter database' => 'Pozměnit databázi',
	'Create database' => 'Vytvořit databázi',
	'SQL command' => 'SQL příkaz',
	'Dump' => 'Export',
	'Logout' => 'Odhlásit',
	'database' => 'databáze',
	'Use' => 'Vybrat',
	'No tables.' => 'Žádné tabulky.',
	'select' => 'vypsat',
	'Create new table' => 'Vytvořit novou tabulku',
	'Item has been deleted.' => 'Položka byla smazána.',
	'Item has been updated.' => 'Položka byla aktualizována.',
	'Item has been inserted.' => 'Položka byla vložena.',
	'Edit' => 'Upravit',
	'Insert' => 'Vložit',
	'Save and insert next' => 'Uložit a vložit další',
	'Delete' => 'Smazat',
	'Database' => 'Databáze',
	'Routines' => 'Procedury',
	'Indexes has been altered.' => 'Indexy byly změněny.',
	'Indexes' => 'Indexy',
	'Alter indexes' => 'Pozměnit indexy',
	'Add next' => 'Přidat další',
	'Language' => 'Jazyk',
	'Select' => 'Vypsat',
	'New item' => 'Nová položka',
	'Search' => 'Vyhledat',
	'Sort' => 'Setřídit',
	'DESC' => 'sestupně',
	'Limit' => 'Limit',
	'No rows.' => 'Žádné řádky.',
	'Action' => 'Akce',
	'edit' => 'upravit',
	'Page' => 'Stránka',
	'Query executed OK, %d row(s) affected.' => array('Příkaz proběhl v pořádku, byl změněn %d záznam.', 'Příkaz proběhl v pořádku, byly změněny %d záznamy.', 'Příkaz proběhl v pořádku, bylo změněno %d záznamů.'),
	'Error in query' => 'Chyba v dotazu',
	'Execute' => 'Provést',
	'Table' => 'Tabulka',
	'Foreign keys' => 'Cizí klíče',
	'Triggers' => 'Triggery',
	'View' => 'Pohled',
	'Unable to select the table' => 'Nepodařilo se vypsat tabulku',
	'Invalid CSRF token. Send the form again.' => 'Neplatný token CSRF. Odešlete formulář znovu.',
	'Comment' => 'Komentář',
	'Default values has been set.' => 'Výchozí hodnoty byly nastaveny.',
	'Default values' => 'Výchozí hodnoty',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Zobrazit komentáře sloupců',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtů'),
	'No commands to execute.' => 'Žádné příkazy k vykonání.',
	'Unable to upload a file.' => 'Nepodařilo se nahrát soubor.',
	'File upload' => 'Nahrání souboru',
	'File uploads are disabled.' => 'Nahrávání souborů není povoleno.',
	'Routine has been called, %d row(s) affected.' => array('Procedura byla zavolána, byl změněn %d záznam.', 'Procedura byla zavolána, byly změněny %d záznamy.', 'Procedura byla zavolána, bylo změněno %d záznamů.'),
	'Call' => 'Zavolat',
	'No MySQL extension' => 'Žádná MySQL extenze',
	'None of supported PHP extensions (%s) are available.' => 'Není dostupná žádná z podporovaných PHP extenzí (%s).',
	'Sessions must be enabled.' => 'Session proměnné musí být povolené.',
	'Session expired, please login again.' => 'Session vypršela, přihlašte se prosím znovu.',
	'Text length' => 'Délka textů',
	'Syntax highlighting' => 'Zvýrazňování syntaxe',
	'Foreign key has been dropped.' => 'Cizí klíč byl odstraněn.',
	'Foreign key has been altered.' => 'Cizí klíč byl změněn.',
	'Foreign key has been created.' => 'Cizí klíč byl vytvořen.',
	'Foreign key' => 'Cizí klíč',
	'Target table' => 'Cílová tabulka',
	'Change' => 'Změnit',
	'Source' => 'Zdroj',
	'Target' => 'Cíl',
	'Add column' => 'Přidat sloupec',
	'Alter' => 'Změnit',
	'Add foreign key' => 'Přidat cizí klíč',
	'ON DELETE' => 'Při smazání',
	'ON UPDATE' => 'Při změně',
	'Index Type' => 'Typ indexu',
	'Column (length)' => 'Sloupec (délka)',
	'View has been dropped.' => 'Pohled byl odstraněn.',
	'View has been altered.' => 'Pohled byl změněn.',
	'View has been created.' => 'Pohled byl vytvořen.',
	'Alter view' => 'Pozměnit pohled',
	'Create view' => 'Vytvořit pohled',
	'Name' => 'Název',
	'Process list' => 'Seznam procesů',
	'%d process(es) has been killed.' => array('Byl ukončen %d proces.', 'Byly ukončeny %d procesy.', 'Bylo ukončeno %d procesů.'),
	'Kill' => 'Ukončit',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Název parametru',
	'Database schema' => 'Schéma databáze',
	'Create procedure' => 'Vytvořit proceduru',
	'Create function' => 'Vytvořit funkci',
	'Routine has been dropped.' => 'Procedura byla odstraněna.',
	'Routine has been altered.' => 'Procedura byla změněna.',
	'Routine has been created.' => 'Procedura byla vytvořena.',
	'Alter function' => 'Změnit funkci',
	'Alter procedure' => 'Změnit proceduru',
	'Return type' => 'Návratový typ',
	'Add trigger' => 'Přidat trigger',
	'Trigger has been dropped.' => 'Trigger byl odstraněn.',
	'Trigger has been altered.' => 'Trigger byl změněn.',
	'Trigger has been created.' => 'Trigger byl vytvořen.',
	'Alter trigger' => 'Změnit trigger',
	'Create trigger' => 'Vytvořit trigger',
	'Time' => 'Čas',
	'Event' => 'Událost',
	'MySQL version: %s through PHP extension %s' => 'Verze MySQL: %s přes PHP extenzi %s',
	'%d row(s)' => array('%d řádek', '%d řádky', '%d řádků'),
	'around %d row(s)' => array('přibližně %d řádek', 'přibližně %d řádky', 'přibližně %d řádků'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'Při změně aktuální čas',
	'Remove' => 'Odebrat',
	'Are you sure?' => 'Opravdu?',
	'Privileges' => 'Oprávnění',
	'Create user' => 'Vytvořit uživatele',
	'User has been dropped.' => 'Uživatel byl odstraněn.',
	'User has been altered.' => 'Uživatel byl změněn.',
	'User has been created.' => 'Uživatel byl vytvořen.',
	'Hashed' => 'Zahašované',
	'Column' => 'Sloupec',
	'Routine' => 'Procedura',
	'Grant' => 'Povolit',
	'Revoke' => 'Zakázat',
	'Error during deleting' => 'Chyba při mazání',
	'%d item(s) have been deleted.' => array('Byl smazán %d záznam.', 'Byly smazány %d záznamy.', 'Bylo smazáno %d záznamů.'),
	'all' => 'vše',
	'Delete selected' => 'Smazat označené',
	'Truncate result' => 'Promazat výsledek',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'Příliš velká POST data. Zmenšete data nebo zvyšte hodnotu konfigurační direktivy "post_max_size".',
	'Logged as: %s' => 'Přihlášen jako: %s',
	'Move up' => 'Přesunout nahoru',
	'Move down' => 'Přesunout dolů',
	'Functions' => 'Funkce',
	'Aggregation' => 'Agregace',
	'Export' => 'Export',
	'Output' => 'Výstup',
	'open' => 'otevřít',
	'save' => 'uložit',
	'Format' => 'Formát',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'skip' => 'přeskočit',
	'Tables' => 'Tabulky',
	'Structure' => 'Struktura',
	'Data' => 'Data',
	'Export selected' => 'Exportovat označené',
	'Export result' => 'Exportovat výsledek',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/cs.inc.php <==
<?php
$translations = array(
	'Login' => 'Přihlásit se',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Odhlášení proběhlo v pořádku.',
	'Invalid credentials.' => 'Neplatné přihlašovací údaje.',
	'Server' => 'Server',
	'Username' => 'Uživatel',
	'Password' => 'Heslo',
	'Select database' => 'Vybrat databázi',
	'Invalid database.' => 'Nesprávná databáze.',
	'Create new database' => 'Vytvořit novou databázi',
	'Table has been dropped.' => 'Tabulka byla odstraněna.',
	'Table has been altered.' => 'Tabulka byla změněna.',
	'Table has been created.' => 'Tabulka byla vytvořena.',
	'Alter table' => 'Pozměnit tabulku',
	'Create table' => 'Vytvořit tabulku',
	'Table name' => 'Název tabulky',
	'engine' => 'úložiště',
	'collation' => 'porovnávání',
	'Column name' => 'Název sloupce',
	'Type' => 'Typ',
	'Length' => 'Délka',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Volby',
	'Save' => 'Uložit',
	'Drop' => 'Odstranit',
	'Database has been dropped.' => 'Databáze byla odstraněna.',
	'Database has been created.' => 'Databáze byla vytvořena.',
	'Database has been renamed.' => 'Databáze byla přejmenována.',
	'Database has been altered.' => 'Databáze byla změněna.',
	'Alter database' => 'Pozměnit databázi',
	'Create database' => 'Vytvořit databázi',
	'SQL command' => 'SQL příkaz',
	'Dump' => 'Export',
	'Logout' => 'Odhlásit',
	'database' => 'databáze',
	'Use' => 'Vybrat',
	'No tables.' => 'Žádné tabulky.',
	'select' => 'vypsat',
	'Create new table' => 'Vytvořit novou tabulku',
	'Item has been deleted.' => 'Položka byla smazána.',
	'Item has been updated.' => 'Položka byla aktualizována.',
	'Item has been inserted.' => 'Položka byla vložena.',
	'Edit' => 'Upravit',
	'Insert' => 'Vložit',
	'Save and insert next' => 'Uložit a vložit další',
	'Delete' => 'Smazat',
	'Database' => 'Databáze',
	'Routines' => 'Procedury a funkce',
	'Indexes has been altered.' => 'Indexy byly změněny.',
	'Indexes' => 'Indexy',
	'Alter indexes' => 'Pozměnit indexy',
	'Add next' => 'Přidat další',
	'Language' => 'Jazyk',
	'Select' => 'Vypsat',
	'New item' => 'Nová položka',
	'Search' => 'Vyhledat',
	'Sort' => 'Setřídit',
	'DESC' => 'sestupně',
	'Limit' => 'Limit',
	'No rows.' => 'Žádné řádky.',
	'Action' => 'Akce',
	'edit' => 'upravit',
	'Page' => 'Stránka',
	'Query executed OK, %d row(s) affected.' => array('Příkaz proběhl v pořádku, byl změněn %d záznam.', 'Příkaz proběhl v pořádku, byly změněny %d záznamy.', 'Příkaz proběhl v pořádku, bylo změněno %d záznamů.'),
	'Error in query' => 'Chyba v dotazu',
	'Execute' => 'Provést',
	'Table' => 'Tabulka',
	'Foreign keys' => 'Cizí klíče',
	'Triggers' => 'Triggery',
	'View' => 'Pohled',
	'Unable to select the table' => 'Nepodařilo se vypsat tabulku',
	'Invalid CSRF token. Send the form again.' => 'Neplatný token CSRF. Odešlete formulář znovu.',
	'Comment' => 'Komentář',
	'Default values has been set.' => 'Výchozí hodnoty byly nastaveny.',
	'Default values' => 'Výchozí hodnoty',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Zobrazit komentáře sloupců',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtů'),
	'No commands to execute.' => 'Žádné příkazy k vykonání.',
	'Unable to upload a file.' => 'Nepodařilo se nahrát soubor.',
	'File upload' => 'Nahrání souboru',
	'File uploads are disabled.' => 'Nahrávání souborů není povoleno.',
	'Routine has been called, %d row(s) affected.' => array('Procedura byla zavolána, byl změněn %d záznam.', 'Procedura byla zavolána, byly změněny %d záznamy.', 'Procedura byla zavolána, bylo změněno %d záznamů.'),
	'Call' => 'Zavolat',
	'No MySQL extension' => 'Žádná MySQL extenze',
	'None of supported PHP extensions (%s) are available.' => 'Není dostupná žádná z podporovaných PHP extenzí (%s).',
	'Sessions must be enabled.' => 'Session proměnné musí být povolené.',
	'Session expired, please login again.' => 'Session vypršela, přihlašte se prosím znovu.',
	'Text length' => 'Délka textů',
	'Syntax highlighting' => 'Zvýrazňování syntaxe',
	'Foreign key has been dropped.' => 'Cizí klíč byl odstraněn.',
	'Foreign key has been altered.' => 'Cizí klíč byl změněn.',
	'Foreign key has been created.' => 'Cizí klíč byl vytvořen.',
	'Foreign key' => 'Cizí klíč',
	'Target table' => 'Cílová tabulka',
	'Change' => 'Změnit',
	'Source' => 'Zdroj',
	'Target' => 'Cíl',
	'Add column' => 'Přidat sloupec',
	'Alter' => 'Změnit',
	'Add foreign key' => 'Přidat cizí klíč',
	'ON DELETE' => 'Při smazání',
	'ON UPDATE' => 'Při změně',
	'Index Type' => 'Typ indexu',
	'Column (length)' => 'Sloupec (délka)',
	'View has been dropped.' => 'Pohled byl odstraněn.',
	'View has been altered.' => 'Pohled byl změněn.',
	'View has been created.' => 'Pohled byl vytvořen.',
	'Alter view' => 'Pozměnit pohled',
	'Create view' => 'Vytvořit pohled',
	'Name' => 'Název',
	'Process list' => 'Seznam procesů',
	'%d process(es) has been killed.' => array('Byl ukončen %d proces.', 'Byly ukončeny %d procesy.', 'Bylo ukončeno %d procesů.'),
	'Kill' => 'Ukončit',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Název parametru',
	'Database schema' => 'Schéma databáze',
	'Create procedure' => 'Vytvořit proceduru',
	'Create function' => 'Vytvořit funkci',
	'Routine has been dropped.' => 'Procedura byla odstraněna.',
	'Routine has been altered.' => 'Procedura byla změněna.',
	'Routine has been created.' => 'Procedura byla vytvořena.',
	'Alter function' => 'Změnit funkci',
	'Alter procedure' => 'Změnit proceduru',
	'Return type' => 'Návratový typ',
	'Add trigger' => 'Přidat trigger',
	'Trigger has been dropped.' => 'Trigger byl odstraněn.',
	'Trigger has been altered.' => 'Trigger byl změněn.',
	'Trigger has been created.' => 'Trigger byl vytvořen.',
	'Alter trigger' => 'Změnit trigger',
	'Create trigger' => 'Vytvořit trigger',
	'Time' => 'Čas',
	'Event' => 'Událost',
	'MySQL version: %s through PHP extension %s' => 'Verze MySQL: %s přes PHP extenzi %s',
	'%d row(s)' => array('%d řádek', '%d řádky', '%d řádků'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'Při změně aktuální čas',
	'Remove' => 'Odebrat',
	'Are you sure?' => 'Opravdu?',
	'Privileges' => 'Oprávnění',
	'Create user' => 'Vytvořit uživatele',
	'User has been dropped.' => 'Uživatel byl odstraněn.',
	'User has been altered.' => 'Uživatel byl změněn.',
	'User has been created.' => 'Uživatel byl vytvořen.',
	'Hashed' => 'Zahašované',
	'Column' => 'Sloupec',
	'Routine' => 'Procedura',
	'Grant' => 'Povolit',
	'Revoke' => 'Zakázat',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'Příliš velká POST data. Zmenšete data nebo zvyšte hodnotu konfigurační direktivy "post_max_size".',
	'Logged as: %s' => 'Přihlášen jako: %s',
	'Move up' => 'Přesunout nahoru',
	'Move down' => 'Přesunout dolů',
	'Functions' => 'Funkce',
	'Aggregation' => 'Agregace',
	'Export' => 'Export',
	'Output' => 'Výstup',
	'open' => 'otevřít',
	'save' => 'uložit',
	'Format' => 'Formát',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'skip' => 'přeskočit',
	'Tables' => 'Tabulky',
	'Structure' => 'Struktura',
	'Data' => 'Data',
	'Event has been dropped.' => 'Událost byla odstraněna.',
	'Event has been altered.' => 'Událost byla změněna.',
	'Event has been created.' => 'Událost byla vytvořena.',
	'Alter event' => 'Pozměnit událost',
	'Create event' => 'Vytvořit událost',
	'At given time' => 'V daný čas',
	'Every' => 'Každých',
	'Events' => 'Události',
	'Schedule' => 'Plán',
	'Start' => 'Začátek',
	'End' => 'Konec',
	'Status' => 'Stav',
	'On completion preserve' => 'Po dokončení zachovat',
	'Tables and views' => 'Tabulky a pohledy',
	'Data Length' => 'Velikost dat',
	'Index Length' => 'Velikost indexů',
	'Data Free' => 'Volné místo',
	'Collation' => 'Porovnávání',
	'Analyze' => 'Analyzovat',
	'Optimize' => 'Optimalizovat',
	'Check' => 'Zkontrolovat',
	'Repair' => 'Opravit',
	'Truncate' => 'Promazat',
	'Tables have been truncated.' => 'Tabulky byly promazány.',
	'Rows' => 'Řádků',
	',' => ' ',
	'Tables have been moved.' => 'Tabulky byly přesunuty',
	'Move to other database' => 'Přesunout do jiné databáze',
	'Move' => 'Přesunout',
	'Engine' => 'Úložiště',
	'Save and continue edit' => 'Uložit a pokračovat v editaci',
	'clone' => 'klonovat',
	'original' => 'původní',
	'%d item(s) have been affected.' => array('Byl ovlivněn %d záznam.', 'Byly ovlivněny %d záznamy.', 'Bylo ovlivněno %d záznamů.'),
	'whole result' => 'celý výsledek',
	'Tables have been dropped.' => 'Tabulky byla odstraněny.',
	'Clone' => 'Klonovat',
);
